@@ -23,6 +23,9 @@ def test_sharepoint():
     AZURE_TENANT_ID = os.getenv('AZURE_TENANT_ID')
     CURRENT_DIRECTORY = os.path.realpath(os.path.dirname(__file__))
 
+    if os.path.exists(CURRENT_DIRECTORY+"/test_cities_delete.csv"):
+        os.remove(CURRENT_DIRECTORY+"/test_cities_delete.csv")
+
     # ---------- STORE File to Sharepoint ------------
     # SharepointUpload(Host, TenantID, ClientID, Secret, SiteName, TargetFilePath, SourceFilePath, FileDescription="", ProxyUse=False, ProxyUrl="", ProxyMethod="https", FileConflict="fail")
     print(CURRENT_DIRECTORY)
@@ -33,7 +36,8 @@ def test_sharepoint():
     Secret=AZURE_CLIENT_SECRET, 
     SiteName="Dataplane Python", 
     TargetFilePath=f"/General/myfile {RUN_ID}.csv",
-    SourceFilePath=CURRENT_DIRECTORY+"/test_cities.csv"
+    SourceFilePath=CURRENT_DIRECTORY+"/test_cities.csv",
+    UploadMethod="File"
     )
     print(rs)
     assert rs["result"]=="OK"
@@ -48,6 +52,7 @@ def test_sharepoint():
     SiteName="Dataplane Python", 
     SharepointFilePath=f"/General/myfile {RUN_ID}.csv",
     LocalFilePath=CURRENT_DIRECTORY+"/test_cities_delete.csv",
+    DownloadMethod="File",
     ProxyUse=False, ProxyUrl="", ProxyMethod="https")
     print(rs)
     assert rs["result"]=="OK"
