@@ -1,11 +1,11 @@
-from dataplane.pipelinerun.data_persist.redis_store import (
-    pipeline_redis_store,
-    pipeline_redis_get,
+from dataplane.pipelinerun.data_persist.pandas_redis_store import (
+    pipeline_pandas_redis_store,
+    pipeline_pandas_redis_get,
 )
 
-from dataplane.pipelinerun.data_persist.s3_store import (
-    pipeline_s3_get,
-    pipeline_s3_store,
+from dataplane.pipelinerun.data_persist.pandas_s3_store import (
+    pipeline_pandas_s3_get,
+    pipeline_pandas_s3_store,
 )
 
 from dataplane.hello import (
@@ -24,10 +24,10 @@ __all__ = [
     "hello",
 
     # Pipeline transfers
-    "pipeline_redis_store", 
-    "pipeline_redis_get", 
-    "pipeline_s3_get", 
-    "pipeline_s3_store",
+    "pipeline_pandas_redis_store", 
+    "pipeline_pandas_redis_get", 
+    "pipeline_pandas_s3_get", 
+    "pipeline_pandas_s3_store",
 
     # Microsoft connectors
     "teams_webhook_send",
