@@ -1,7 +1,7 @@
 
 import os
-from .redis_store import pipeline_redis_store
-from .redis_store import pipeline_redis_get
+from .pandas_redis_store import pipeline_pandas_redis_store
+from .pandas_redis_store import pipeline_pandas_redis_get
 import redis
 from datetime import timedelta
 from nanoid import generate
@@ -29,14 +29,14 @@ def test_redis_store():
     # ---------- STORE PARQUET TO REDIS ------------
     
     # Store the data with key hello - run id will be attached
-    rs = pipeline_redis_store(StoreKey="hello", DataFrame=df, Redis=redisConnect, Expire=True, ExpireDuration=timedelta(minutes=15))
+    rs = pipeline_pandas_redis_store(StoreKey="hello", DataFrame=df, Redis=redisConnect, Expire=True, ExpireDuration=timedelta(minutes=15))
     print(rs)
     assert rs["result"]=="OK"
 
     # ---------- RETRIEVE PARQUET FROM REDIS ------------
 
     # Get the data
-    rsget = pipeline_redis_get(StoreKey="hello", Redis=redisConnect)
+    rsget = pipeline_pandas_redis_get(StoreKey="hello", Redis=redisConnect)
     print(rsget)
     df = rsget["dataframe"]
     print(df.shape[0])
